summaryrefslogtreecommitdiffstats
path: root/ksmserver/shutdown.cpp
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-06-08 21:02:38 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-06-08 21:02:38 -0500
commit8a61818a86d7d7f6b6332790d80b50a8b3a73146 (patch)
tree8f6a474c1f659a5cd2435744bd02b4ecea5b54c4 /ksmserver/shutdown.cpp
parent5b597230f0b8f2aed44816ffc3ef5d6f01ef44c5 (diff)
downloadtdebase-8a61818a86d7d7f6b6332790d80b50a8b3a73146.tar.gz
tdebase-8a61818a86d7d7f6b6332790d80b50a8b3a73146.zip
Add check box control to enable/disable the session exit (feedback)
dialog box. This resolves bug report 681.
Diffstat (limited to 'ksmserver/shutdown.cpp')
-rw-r--r--ksmserver/shutdown.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/ksmserver/shutdown.cpp b/ksmserver/shutdown.cpp
index 2ba3df92a..fc55c5d7a 100644
--- a/ksmserver/shutdown.cpp
+++ b/ksmserver/shutdown.cpp
@@ -167,10 +167,10 @@ void KSMServer::shutdownInternal( KApplication::ShutdownConfirm confirm,
if (sdmode == KApplication::ShutdownModeDefault)
sdmode = KApplication::ShutdownModeInteractive;
- // shall we show a nice fancy logout screen?
- bool showFancyLogout = KConfigGroup(KGlobal::config(), "Logout").readBoolEntry("showFancyLogout", true);
+ // shall we show a logout status dialog box?
+ bool showLogoutStatusDlg = KConfigGroup(KGlobal::config(), "Logout").readBoolEntry("showLogoutStatusDlg", true);
- if (showFancyLogout) {
+ if (showLogoutStatusDlg) {
KSMShutdownIPFeedback::start();
}
@@ -235,7 +235,7 @@ void KSMServer::shutdownInternal( KApplication::ShutdownConfirm confirm,
// Set the real desktop background to black so that exit looks
// clean regardless of what was on "our" desktop.
- if (!showFancyLogout) {
+ if (!showLogoutStatusDlg) {
TQT_TQWIDGET(kapp->desktop())->setBackgroundColor( Qt::black );
}
state = Shutdown;
@@ -275,7 +275,7 @@ void KSMServer::shutdownInternal( KApplication::ShutdownConfirm confirm,
completeShutdownOrCheckpoint();
}
else {
- if (showFancyLogout) {
+ if (showLogoutStatusDlg) {
KSMShutdownIPFeedback::stop();
}
}
@@ -525,8 +525,8 @@ void KSMServer::completeShutdownOrCheckpoint()
if ( waitForPhase2 )
return;
- bool showFancyLogout = KConfigGroup(KGlobal::config(), "Logout").readBoolEntry("showFancyLogout", true);
- if (showFancyLogout && state != Checkpoint) {
+ bool showLogoutStatusDlg = KConfigGroup(KGlobal::config(), "Logout").readBoolEntry("showLogoutStatusDlg", true);
+ if (showLogoutStatusDlg && state != Checkpoint) {
KSMShutdownIPFeedback::showit(); // hide the UGLY logout process from the user
shutdownNotifierIPDlg = KSMShutdownIPDlg::showShutdownIP();
while (!KSMShutdownIPFeedback::ispainted()) {